ReferralSystemClass class

Constructors

ReferralSystemClass({String? id, String? name, String? clientId, String? status, String? desc, String? entryPointId, dynamic audience, int? limit, bool? targetAllUsers, List<Task>? tasks, List<CodeGenerationRule>? codeGenerationRules, DateTime? createdAt, DateTime? updatedAt, int? v})
ReferralSystemClass.fromJson(Map<String, dynamic> json)
factory

Properties

audience ↔ dynamic
getter/setter pair
clientId String?
getter/setter pair
codeGenerationRules List<CodeGenerationRule>?
getter/setter pair
createdAt DateTime?
getter/setter pair
desc String?
getter/setter pair
entryPointId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
limit int?
getter/setter pair
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
getter/setter pair
targetAllUsers bool?
getter/setter pair
tasks List<Task>?
getter/setter pair
updatedAt DateTime?
getter/setter pair
v int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited