Task class

Constructors

Task({String? title, String? event, int? frequency, dynamic conditions, List<ReferreReward>? referrerRewards, List<ReferreReward>? referreeRewards, String? id})
Task.fromJson(Map<String, dynamic> json)
factory

Properties

conditions ↔ dynamic
getter/setter pair
event String?
getter/setter pair
frequency int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
referreeRewards List<ReferreReward>?
getter/setter pair
referrerRewards List<ReferreReward>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited