UserReferral class

Constructors

UserReferral({String? id, String? userId, int? noOfReferrals, List? usersReferred, List? tasksCompleted, List? rewardsWon, DateTime? createdAt, DateTime? updatedAt, int? v})
UserReferral.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
noOfReferrals int?
getter/setter pair
rewardsWon List?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tasksCompleted List?
getter/setter pair
updatedAt DateTime?
getter/setter pair
userId String?
getter/setter pair
usersReferred List?
getter/setter pair
v int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited