CodeGenerationRule class

Constructors

CodeGenerationRule({int? position, String? type, String? value, String? attribute, int? startLength, int? endLength, String? filler, bool? randomElement, int? length, bool? onlyDigits, String? id})
CodeGenerationRule.fromJson(Map<String, dynamic> json)
factory

Properties

attribute String?
getter/setter pair
endLength int?
getter/setter pair
filler String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
length int?
getter/setter pair
onlyDigits bool?
getter/setter pair
position int?
getter/setter pair
randomElement bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startLength int?
getter/setter pair
type String?
getter/setter pair
value String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited